Stan Math Library: stan/math/prim/scal/fun/abs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

abs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_ABS_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_ABS_HPP
3
4 #include <cmath>
5
6 namespace stan {
7
8 namespace math {
9
19 double abs(double x) {
20 return std::fabs(x);
21 }
22
23 }
24 }
25
26 #endif
stan::math::abs
fvar< T > abs(const fvar< T > &x)
Definition: abs.hpp:15
stan::math::fabs
fvar< T > fabs(const fvar< T > &x)
Definition: fabs.hpp:14
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.